<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Network Assistant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>&amp;Close</source>
        <translation>C&amp;hiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>IP address</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Hardware detected</source>
        <translation>Hardware rilevato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Abilita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="706"/>
        <source>Re-scan</source>
        <translation>Ri-scansiona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Abilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Venditore</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Prodotto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Disabilita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Active interface</source>
        <translation>Interfaccia attiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="435"/>
        <source>WiFi status</source>
        <translation>WiFi status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Sblocca tutti i dispositivi software/hardware wireless chiusi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Unblock WiFi Devices</source>
        <translation>Sblocca i Dispositivi WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>Linux drivers</source>
        <translation>Linux drivers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Associated Linux drivers</source>
        <translation>Drivers Linux associati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Load Driver</source>
        <translation>Carica Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Unload Driver</source>
        <translation>Scarica Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation>Blocca driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Windows drivers</source>
        <translation>Drivers Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>Available Windows drivers</source>
        <translation>Drivers Windows disponibili</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Remove Driver</source>
        <translation>Rimuovi Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Add Driver</source>
        <translation>Aggiungi Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>About NDISwrapper</source>
        <translation>Informazioni su NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Install NDISwrapper</source>
        <translation>Installa NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Per poter utilizzare i driver Windows è necessario prima installare NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Disinstalla NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="795"/>
        <source>Net diagnostics</source>
        <translation>Diagnostica di rete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>URL del Target:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="823"/>
        <source>Packets</source>
        <translation>Pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="885"/>
        <location filename="../mainwindow.ui" line="1008"/>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <location filename="../mainwindow.ui" line="1022"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>Indirizzo IP dal router:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Indirizzo IP esterno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Interfaccia: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Driver: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Descrizione: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Prodotto: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Venditore: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Abilitato: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Copia &amp;Tutto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute non è installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute non è installato, vuoi installarlo ora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute non è stato installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Traceroute non può essere installato. Questo probabilmente significa che stai usando il LiveCD o che non ti è possibile collegarti ai repository del software.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute  non è installato e, poichè non si riesce a rilevare alcuna connessione internet, al momento non si può intallare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Nessun host di destinazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Compilare il campo dell&apos;host di destinazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Drivers caricati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Drivers non caricati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Driver bloccati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Driver Broadcom bloccati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper non è installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>driver installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>e in uso da</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>Cambiare driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Driver rimosso dalla lista dei bloccati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Driver rimosso dalla lista dei bloccati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Modulo bloccato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Installazione completata con successo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>E&apos; incorso un errore, non è possibile compilare il driver ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>E&apos; incorso un errore, non è possibile installare ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>E&apos; incorso un errore durante la rimozione di Ndiswrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Sblocca driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>abilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>L a scheda WiFi è spenta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Individua la posizione del driver di Windows che desideri aggiungere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation> File (*.inf) d&apos;informazione di installazione di Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>File *.sys non trovato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>I files *.sys dovrebbero essere nella stessa posizione del file *.inf. %1 non si riesce a trovare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>il file sys di referenza non si trova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Il file sys per il driver non può essere determinato dopo l&apos;analisi del file inf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Il driver Ndiswrapper è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Non si riesce a sbloccare i dispositivi.
Il dispositivo/i WiFi  potrebbe essere già sbloccato/i.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Dispositivi WiFi sbloccati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Programma di MX Linux per la configurazione e risoluzione dei problemi di rete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Copyright (c) MEPIS LLC e MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Driver caricato con successo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Driver scaricato con successo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Impossibile caricare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Impossibile scaricare</translation>
    </message>
</context>
</TS>
